.. |casadi| replace:: CasADi
.. |SX| replace:: :class:`SX`
.. |DM| replace:: :class:`DM`
.. |MX| replace:: :class:`MX`
.. |Function| replace:: :class:`Function`
.. |FunctionInternal| replace:: :class:`FunctionInternal`
.. |Sparsity| replace:: :class:`Sparsity`
.. |Callback| replace:: :class:`Callback`
.. |DaeBuilder| replace:: :class:`DaeBuilder`

.. exec-block-add-header:: python

  from casadi import *

.. exec-block-add-header:: octave

  import casadi.*

.. exec-block-add-filter::

  ******************************************************************************
  This program contains Ipopt, a library for large-scale nonlinear optimization.
   Ipopt is released as open source code under the Eclipse Public License (EPL).
           For more information visit http://projects.coin-or.org/Ipopt
  ******************************************************************************
